# This is a simple api wrapper for urban dictionary's api
## Example:
```py
from urbanpy import urban
# Gets the first definiton in an array of definitions and than gets the definiton value from the dictionary.
print(urban.getDef("Bruh")[0]["definition"])

```
